import setuptools

setuptools.setup(
	name='R2taps',
	version='1.1',
	author='SUHOFRUKT',
	author_email='di.momopog@yandex.ru',
	description='xdxdxdxdx',
	packages=['R2taps'],
	classifiers=[
		"Programming Language :: Python :: 3",
		"License :: OSI Approved :: MIT License",
		"Operating System :: OS Independent",
	],
	python_requires='>=3.6',
)